Crate masterbongo_core

Crate masterbongo_core 

masterbongo_core

  • provides core functionality
  • includes traits which can be derived when used with the masterbongo_derive crate

Macros

masterbongo
Macro to masterbongo the user with multiple messages.

Traits

MasterBongo
This trait can be implemented using the derive macro with the optional derive feature.

Functions

greet
Main function to masterbongo the user.