masterbongo_core
- provides core functionality
- includes traits which can be derived when used with the
masterbongo_derivecrate
Macros
- masterbongo
- Macro to masterbongo the user with multiple messages.
Traits
- Master
Bongo - This trait can be implemented using the derive macro
with the optional
derivefeature.
Functions
- greet
- Main function to masterbongo the user.